/* Initialization */
#include "Solar_model.h"
#include "Solar_11mix.h"
#include "Solar_12jac.h"
#if defined(__cplusplus)
extern "C" {
#endif

void Solar_functionInitialEquations_0(DATA *data, threadData_t *threadData);

/*
equation index: 1
type: SIMPLE_ASSIGN
heatSource.ISignal.signal = 0.0
*/
void Solar_eqFunction_1(DATA *data, threadData_t *threadData)
{
  TRACE_PUSH
  const int equationIndexes[2] = {1,1};
  (data->localData[0]->realVars[5]/* heatSource.ISignal.signal variable */)  = 0.0;
  TRACE_POP
}

/*
equation index: 2
type: SIMPLE_ASSIGN
solarCollector.Tsky = 0.0552 * T_atm.k ^ 1.5
*/
void Solar_eqFunction_2(DATA *data, threadData_t *threadData)
{
  TRACE_PUSH
  const int equationIndexes[2] = {1,2};
  modelica_real tmp0;
  modelica_real tmp1;
  modelica_real tmp2;
  modelica_real tmp3;
  modelica_real tmp4;
  modelica_real tmp5;
  modelica_real tmp6;
  tmp0 = (data->simulationInfo->realParameter[16]/* T_atm.k PARAM */) ;
  tmp1 = 1.5;
  if(tmp0 < 0.0 && tmp1 != 0.0)
  {
    tmp3 = modf(tmp1, &tmp4);
    
    if(tmp3 > 0.5)
    {
      tmp3 -= 1.0;
      tmp4 += 1.0;
    }
    else if(tmp3 < -0.5)
    {
      tmp3 += 1.0;
      tmp4 -= 1.0;
    }
    
    if(fabs(tmp3) < 1e-10)
      tmp2 = pow(tmp0, tmp4);
    else
    {
      tmp6 = modf(1.0/tmp1, &tmp5);
      if(tmp6 > 0.5)
      {
        tmp6 -= 1.0;
        tmp5 += 1.0;
      }
      else if(tmp6 < -0.5)
      {
        tmp6 += 1.0;
        tmp5 -= 1.0;
      }
      if(fabs(tmp6) < 1e-10 && ((unsigned long)tmp5 & 1))
      {
        tmp2 = -pow(-tmp0, tmp3)*pow(tmp0, tmp4);
      }
      else
      {
        throwStreamPrint(threadData, "%s:%d: Invalid root: (%g)^(%g)", __FILE__, __LINE__, tmp0, tmp1);
      }
    }
  }
  else
  {
    tmp2 = pow(tmp0, tmp1);
  }
  if(isnan(tmp2) || isinf(tmp2))
  {
    throwStreamPrint(threadData, "%s:%d: Invalid root: (%g)^(%g)", __FILE__, __LINE__, tmp0, tmp1);
  }
  (data->localData[0]->realVars[12]/* solarCollector.Tsky variable */)  = (0.0552) * (tmp2);
  TRACE_POP
}

/*
equation index: 3
type: SIMPLE_ASSIGN
solarCollector.IAM = cos(0.0174532925199433 * angle_incidence.k)
*/
void Solar_eqFunction_3(DATA *data, threadData_t *threadData)
{
  TRACE_PUSH
  const int equationIndexes[2] = {1,3};
  (data->localData[0]->realVars[9]/* solarCollector.IAM variable */)  = cos((0.0174532925199433) * ((data->simulationInfo->realParameter[18]/* angle_incidence.k PARAM */) ));
  TRACE_POP
}

/*
equation index: 4
type: SIMPLE_ASSIGN
solarCollector.AReflector = 4.0 * solarCollector.f * tan(0.008726646259971648 * solarCollector.RimAngle) * solarCollector.L
*/
void Solar_eqFunction_4(DATA *data, threadData_t *threadData)
{
  TRACE_PUSH
  const int equationIndexes[2] = {1,4};
  (data->localData[0]->realVars[7]/* solarCollector.AReflector variable */)  = (4.0) * (((data->simulationInfo->realParameter[47]/* solarCollector.f PARAM */) ) * ((tan((0.008726646259971648) * ((data->simulationInfo->realParameter[40]/* solarCollector.RimAngle PARAM */) ))) * ((data->simulationInfo->realParameter[36]/* solarCollector.L PARAM */) )));
  TRACE_POP
}

/*
equation index: 5
type: SIMPLE_ASSIGN
solarCollector.AGlass = 3.141592653589793 * solarCollector.DGlass * solarCollector.L
*/
void Solar_eqFunction_5(DATA *data, threadData_t *threadData)
{
  TRACE_PUSH
  const int equationIndexes[2] = {1,5};
  (data->localData[0]->realVars[6]/* solarCollector.AGlass variable */)  = (3.141592653589793) * (((data->simulationInfo->realParameter[28]/* solarCollector.DGlass PARAM */) ) * ((data->simulationInfo->realParameter[36]/* solarCollector.L PARAM */) ));
  TRACE_POP
}

/*
equation index: 6
type: SIMPLE_ASSIGN
solarCollector.dM = 0.7853981633974483 * solarCollector.rho_glass * ((solarCollector.DGlass + 2.0 * solarCollector.e) ^ 2.0 - solarCollector.DGlass ^ 2.0) * solarCollector.L
*/
void Solar_eqFunction_6(DATA *data, threadData_t *threadData)
{
  TRACE_PUSH
  const int equationIndexes[2] = {1,6};
  modelica_real tmp7;
  modelica_real tmp8;
  tmp7 = (data->simulationInfo->realParameter[28]/* solarCollector.DGlass PARAM */)  + (2.0) * ((data->simulationInfo->realParameter[46]/* solarCollector.e PARAM */) );
  tmp8 = (data->simulationInfo->realParameter[28]/* solarCollector.DGlass PARAM */) ;
  (data->localData[0]->realVars[21]/* solarCollector.dM variable */)  = (0.7853981633974483) * (((data->simulationInfo->realParameter[49]/* solarCollector.rho_glass PARAM */) ) * (((tmp7 * tmp7) - ((tmp8 * tmp8))) * ((data->simulationInfo->realParameter[36]/* solarCollector.L PARAM */) )));
  TRACE_POP
}

/*
equation index: 7
type: SIMPLE_ASSIGN
solarCollector.ATube = 3.141592653589793 * solarCollector.DTube * solarCollector.L
*/
void Solar_eqFunction_7(DATA *data, threadData_t *threadData)
{
  TRACE_PUSH
  const int equationIndexes[2] = {1,7};
  (data->localData[0]->realVars[8]/* solarCollector.ATube variable */)  = (3.141592653589793) * (((data->simulationInfo->realParameter[29]/* solarCollector.DTube PARAM */) ) * ((data->simulationInfo->realParameter[36]/* solarCollector.L PARAM */) ));
  TRACE_POP
}

/*
equation index: 8
type: SIMPLE_ASSIGN
solarCollector.TauAlphaN = solarCollector.TauN * solarCollector.AlphaN / (1.0 + (-1.0 + solarCollector.TauN) * solarCollector.AlphaN)
*/
void Solar_eqFunction_8(DATA *data, threadData_t *threadData)
{
  TRACE_PUSH
  const int equationIndexes[2] = {1,8};
  (data->localData[0]->realVars[11]/* solarCollector.TauAlphaN variable */)  = ((data->simulationInfo->realParameter[43]/* solarCollector.TauN PARAM */) ) * (DIVISION_SIM((data->simulationInfo->realParameter[26]/* solarCollector.AlphaN PARAM */) ,1.0 + (-1.0 + (data->simulationInfo->realParameter[43]/* solarCollector.TauN PARAM */) ) * ((data->simulationInfo->realParameter[26]/* solarCollector.AlphaN PARAM */) ),"1.0 + (-1.0 + solarCollector.TauN) * solarCollector.AlphaN",equationIndexes));
  TRACE_POP
}
extern void Solar_eqFunction_36(DATA *data, threadData_t *threadData);

extern void Solar_eqFunction_35(DATA *data, threadData_t *threadData);


/*
equation index: 11
type: SIMPLE_ASSIGN
$DER.Paroi3.Tp[1] = 0.0
*/
void Solar_eqFunction_11(DATA *data, threadData_t *threadData)
{
  TRACE_PUSH
  const int equationIndexes[2] = {1,11};
  (data->localData[0]->realVars[2]/* der(Paroi3.Tp[1]) STATE_DER */)  = 0.0;
  TRACE_POP
}

/*
equation index: 12
type: SIMPLE_ASSIGN
$DER.solarCollector.Tglass[1] = 0.0
*/
void Solar_eqFunction_12(DATA *data, threadData_t *threadData)
{
  TRACE_PUSH
  const int equationIndexes[2] = {1,12};
  (data->localData[0]->realVars[3]/* der(solarCollector.Tglass[1]) STATE_DER */)  = 0.0;
  TRACE_POP
}

void Solar_eqFunction_13(DATA*, threadData_t*);
void Solar_eqFunction_14(DATA*, threadData_t*);
void Solar_eqFunction_15(DATA*, threadData_t*);
void Solar_eqFunction_16(DATA*, threadData_t*);
void Solar_eqFunction_17(DATA*, threadData_t*);
void Solar_eqFunction_18(DATA*, threadData_t*);
void Solar_eqFunction_19(DATA*, threadData_t*);
void Solar_eqFunction_20(DATA*, threadData_t*);
void Solar_eqFunction_21(DATA*, threadData_t*);
/*
equation index: 33
indexNonlinear: 0
type: NONLINEAR

vars: {solarCollector.Tglass[1]}
eqns: {13, 14, 15, 16, 17, 18, 19, 20, 21}
*/
void Solar_eqFunction_33(DATA *data, threadData_t *threadData)
{
  TRACE_PUSH
  const int equationIndexes[2] = {1,33};
  int retValue;
  if(ACTIVE_STREAM(LOG_DT))
  {
    infoStreamPrint(LOG_DT, 1, "Solving nonlinear system 33 (STRICT TEARING SET if tearing enabled) at time = %18.10e", data->localData[0]->timeValue);
    messageClose(LOG_DT);
  }
  /* get old value */
  data->simulationInfo->nonlinearSystemData[0].nlsxOld[0] = (data->localData[0]->realVars[1]/* solarCollector.Tglass[1] STATE(1) */) ;
  retValue = solve_nonlinear_system(data, threadData, 0);
  /* check if solution process was successful */
  if (retValue > 0){
    const int indexes[2] = {1,33};
    throwStreamPrintWithEquationIndexes(threadData, indexes, "Solving non-linear system 33 failed at time=%.15g.\nFor more information please use -lv LOG_NLS.", data->localData[0]->timeValue);
  }
  /* write solution */
  (data->localData[0]->realVars[1]/* solarCollector.Tglass[1] STATE(1) */)  = data->simulationInfo->nonlinearSystemData[0].nlsx[0];
  TRACE_POP
}

/*
equation index: 34
type: SIMPLE_ASSIGN
solarCollector.WConvWall[1] = 0.0
*/
void Solar_eqFunction_34(DATA *data, threadData_t *threadData)
{
  TRACE_PUSH
  const int equationIndexes[2] = {1,34};
  (data->localData[0]->realVars[17]/* solarCollector.WConvWall[1] variable */)  = 0.0;
  TRACE_POP
}
OMC_DISABLE_OPT
void Solar_functionInitialEquations_0(DATA *data, threadData_t *threadData)
{
  TRACE_PUSH
  Solar_eqFunction_1(data, threadData);
  Solar_eqFunction_2(data, threadData);
  Solar_eqFunction_3(data, threadData);
  Solar_eqFunction_4(data, threadData);
  Solar_eqFunction_5(data, threadData);
  Solar_eqFunction_6(data, threadData);
  Solar_eqFunction_7(data, threadData);
  Solar_eqFunction_8(data, threadData);
  Solar_eqFunction_36(data, threadData);
  Solar_eqFunction_35(data, threadData);
  Solar_eqFunction_11(data, threadData);
  Solar_eqFunction_12(data, threadData);
  Solar_eqFunction_33(data, threadData);
  Solar_eqFunction_34(data, threadData);
  TRACE_POP
}

int Solar_functionInitialEquations(DATA *data, threadData_t *threadData)
{
  TRACE_PUSH

  data->simulationInfo->discreteCall = 1;
  Solar_functionInitialEquations_0(data, threadData);
  data->simulationInfo->discreteCall = 0;
  
  TRACE_POP
  return 0;
}

/* No Solar_functionInitialEquations_lambda0 function */

int Solar_functionRemovedInitialEquations(DATA *data, threadData_t *threadData)
{
  TRACE_PUSH
  const int *equationIndexes = NULL;
  double res = 0.0;

  
  TRACE_POP
  return 0;
}


#if defined(__cplusplus)
}
#endif

